#!/usr/bin/env python3

import fire
import traceback
from libnmap.parser import NmapParser
from os import path, makedirs

VERSION = '1.0.2'
OUTPUT_DIR = 'ewsnmap-output'

def banner():
  print(
      '''
        ███████╗███████╗ ██████╗███████╗██╗
        ██╔════╝██╔════╝██╔════╝██╔════╝██║
        ███████╗█████╗  ██║     ███████╗██║
        ╚════██║██╔══╝  ██║     ╚════██║██║
        ███████║███████╗╚██████╗███████║██║
        ╚══════╝╚══════╝ ╚═════╝╚══════╝╚═╝

        https://wwww.secsi.io - https://github.com/cybersecsi/ews-nmap
      ''')  

def info(msg):
    print("[+] {}".format(msg))

def err(msg):
    traceback.print_exc()
    print("[-] ERR:{}".format(msg))

def check_or_create_dir(dir_path):
    exists = path.exists(dir_path)

    if not exists:
        # Create a new directory because it does not exist 
        makedirs(dir_path)
        info(f"Directory {dir_path} created")

def process(nmap_xml_file,  output_dir = OUTPUT_DIR, output = 'output.txt', append=False):
    """
    Extract web servers from an Nmap XML file
    """
    targets = []

    info(f"Opening XML file {nmap_xml_file}")
    nmap_report = NmapParser.parse_fromfile(nmap_xml_file)
    for host in nmap_report.hosts:
        #if host.is_up():
        for service in host.services:
            if service.state == 'open':
                if 'https' in service.service:
                    targets.append("https://%s:%s" % (host.address, service.port))
                    info("https://%s:%s" % (host.address, service.port))

                elif 'http' in service.service:
                    targets.append("http://%s:%s" % (host.address, service.port))
                    info("http://%s:%s" % (host.address, service.port))

                if 'HTTP/' in service.servicefp:
                    targets.append("http://%s:%s" % (host.address, service.port))
                    info("http://%s:%s" % (host.address, service.port))

    check_or_create_dir(output_dir)

    file_mode = 'a+' if append else 'w'

    with open(path.join(output_dir, output), file_mode, encoding='utf-8', newline='') as file:
        info(f"Store evidences in {path.join(output_dir, output)}")
        for target in targets:
            file.write(f"{target}\n")
        info("File correctly created!")

def main():
    try:
        banner()
        fire.Fire(process)
    except Exception as e:
        err(str(e))

if __name__ == '__main__':
    main()


#!/usr/bin/env python3
"""Setup for ews-nmap."""

from setuptools import find_packages, setup
from pathlib import Path

def read(rel_path, fix_header=False):
    init = Path(__file__).resolve().parent / rel_path
    initial_content = init.read_text('utf-8', 'ignore')
    if fix_header:
        fixed_header = '<h1 align="center"><img src="https://raw.githubusercontent.com/cybersecsi/ews-nmap/main/assets/logo-light-mode.png" alt= "nmap" width="300px"></h1>'
        content = fixed_header + initial_content.split('</h1>')[1]
        return content
    else:
        return initial_content

def get_version():
    ver_path = 'ewsnmap/ewsnmap.py'
    for line in read(ver_path).splitlines():
        if line.startswith('VERSION'):
            return line.split('\'')[1]
    raise RuntimeError('Unable to find version string.')

setup(
    name='ews-nmap',
    version=get_version(),
    description = "Extract web servers from an Nmap XML file",
    author='SecSI',
    author_email='dev@secsi.io',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Information Technology',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Security'
    ],
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=3.8',
    entry_points={
        'console_scripts': [
            'ewsnmap = ewsnmap:main'
        ],
    },
    url='',
    long_description=read('README.md', fix_header=True),
    long_description_content_type='text/markdown',
    install_requires=[
        'fire',
        'python-libnmap',
        'six',
        'termcolor'
      ],
)